@@ -1,3 +1,4 @@
+import os
 from pathlib import Path
 from typing import Optional, Callable
 
@@ -39,6 +40,17 @@ class Adder:
 
         config_path = _determine_config_path(out_root, Path(repo.working_dir), add_mode)
 
+        if add_mode == AddMode.USER:
+            # No need to use git if adding for user
+            config_manager.add_template_source(
+                template,
+                config_path,
+                target_version=target_version,
+                project_root=Path(repo.working_dir),  # type: ignore
+            )
+            return
+
+        # Local or project config, add in git
         _add_operation_via_branches(
             lambda: config_manager.add_template_source(
                 template,
@@ -74,26 +86,65 @@ class Adder:
 
         project_root = Path(repo.working_dir)
         config_path = _determine_config_path(out_root, project_root, add_mode)
+        expanded_out_root = (
+            out_root.absolute() if add_mode == AddMode.USER else out_root
+        )
+
+        if add_mode == AddMode.USER:
+            # No need to commit config changes for user
+            config_manager.add_applied_template(
+                template,
+                config_path,
+                data=data,
+                project_root=project_root,
+                out_root=expanded_out_root,
+            )
+        else:
+            # TODO: restructure the current path logic into _add_operation_via_branches
+            #  as it will also be needed for other operations.
+            # Commit changes for local and project
+            cwd = Path(os.getcwd())
+            absolute_out_root = out_root.absolute()
+            def make_dirs_add_applied_template():
+                # Need to ensure that both cwd and out root exist on the template branch
+                for p in [cwd, absolute_out_root]:
+                    if not p.exists():
+                        p.mkdir(parents=True)
+                # If cwd was deleted when switching branches, need to navigate back there
+                # or os.getcwd will throw a FileNotExistsError (which also breaks path.absolute())
+                os.chdir(cwd)
+
+                config_manager.add_applied_template(
+                    template,
+                    config_path,
+                    data=data,
+                    project_root=project_root,
+                    out_root=expanded_out_root,
+                )
+
+            _add_operation_via_branches(
+                make_dirs_add_applied_template,
+                repo,
+                _add_template_commit_message(
+                    template, out_root, Path(repo.working_dir)
+                ),
+                merged_branch_name=merged_branch_name,
+                template_branch_name=template_branch_name,
+            )
+
+            # Folder may have been deleted again while switching branches, so
+            # need to set cwd again
+            os.chdir(cwd)
 
         template_update = TemplateUpdate(
             template=template,
             config_location=config_path,
             index=config_manager.get_num_applied_templates_in_child_config(
                 config_path, project_root=project_root
-            ),
+            ) - 1,
             data=data,
         )
 
-        _add_operation_via_branches(
-            lambda: config_manager.add_applied_template(
-                template, config_path, data=data, project_root=project_root
-            ),
-            repo,
-            _add_template_commit_message(template, out_root, Path(repo.working_dir)),
-            merged_branch_name=merged_branch_name,
-            template_branch_name=template_branch_name,
-        )
-
         updater.update(
             repo,
             [template_update],
@@ -119,6 +170,18 @@ class Adder:
 
         path = Path(repo.working_dir)
 
+        if user:
+            # Simply init the project for the user
+            config_manager.add_project(
+                path=path,
+                default_add_mode=default_add_mode,
+                user=user,
+                merged_branch_name=merged_branch_name,
+                template_branch_name=template_branch_name,
+            )
+            return
+
+        # Config resides in project, so add it via branches
         _add_operation_via_branches(
             lambda: config_manager.add_project(
                 path=path,
